@@ -43,7 +43,7 @@ int authFtpse(char *userid, char *passwd)
   char* port;      /* auth server port */
   SSL_CTX    *ctx;
   SSL        *ssl;
-  SSL_METHOD *meth;
+  const SSL_METHOD *meth;
 
   /* get auth server address */
   serverAddr=GetConfValue("AuthServer/Address");
@@ -192,7 +192,7 @@ int authFtpsi(char *userid, char *passwd)
   char* port;      /* auth server port */
   SSL_CTX    *ctx;
   SSL        *ssl;
-  SSL_METHOD *meth;
+  const SSL_METHOD *meth;
 
   /* get auth server address */
   serverAddr=GetConfValue("AuthServer/Address");
