@@ -57,9 +57,9 @@ int authPam(char *userid, char *passwd)
   serviceNameInConf=GetConfValue("AuthServer/ServiceName");
 
   if(isNull(serviceNameInConf)){
-    strncpy(serviceName, PAMSERVICENAME, ADDRMAXLN);
+    strlcpy(serviceName, PAMSERVICENAME, ADDRMAXLN);
   }else{
-    strncpy(serviceName, serviceNameInConf, ADDRMAXLN);
+    strlcpy(serviceName, serviceNameInConf, ADDRMAXLN);
   }
   
   if(!userid || !passwd) return DENY;
