@@ -1,6 +1,6 @@
 /**************************************************
 opengate server
- module for getting parameters from conf file
+ module for getting parameters from configuration file
 
 Copyright (C) 2006 Opengate Project Team
 Written by Yoshiaki Watanabe
@@ -26,9 +26,12 @@ Programmed by Yoshiaki WATANABE
 
 **************************************************/
 #include "opengatesrv.h"
-#include "../ezxml/ezxml.h"
+#include "../ezxml/ezxml.h"  /* XML management library */
 
+/* this value should match the corresponding value in config file */
+/* prepared for checking the use of proper config file */
 #define CONFIG_VERSION "1.5.13"
+
 #define SEPARATOR "/"
 
 int debug=0;
@@ -44,7 +47,8 @@ char *GetConfAuthServer(char *name);
 
 /**************************************************/
 /* Prepare Conf file to use                       */
-/* this is called before syslog setup             */
+/* this should be called before syslog setup,     */
+/* because syslog parameters are loaded from conf */
 /**************************************************/
 int openConfFile(void)
 {
@@ -52,10 +56,10 @@ int openConfFile(void)
   char *s;
   char *errMsg;
 
-  /* parse file and make tree */
+  /* parse conf file and make xml tree */
   if((xmlRoot = ezxml_parse_file(CONFIGFILE))==NULL){
 
-    /* as the syslog is not prepared, error is send to web*/
+    /* as the syslog is not prepared, error is send to web */
     strlcpy(buff, "<H3>Error: Opengate configuration file ",BUFFMAXLN);
     strlcat(buff, CONFIGFILE,BUFFMAXLN);
     strlcat(buff, " is not found. Call the administrator.</H3><BR>",BUFFMAXLN);
@@ -114,6 +118,7 @@ int openConfFile(void)
 
 /**************************************************/
 /*  initialize the Config                         */
+/*  at now, the debug option loading only         */
 /**************************************************/
 void initConf(void)
 {
@@ -126,13 +131,15 @@ void initConf(void)
 /**************************************************/
 void closeConfFile(void)
 {
+  /* free memory area for xml tree */
   if(xmlRoot!=NULL)ezxml_free(xmlRoot);
 }
 
 /**************************************************/
-/* Setup pointer to the matched ExtraSet          */ 
+/* Setup pointer to the matched ExtraSet          */
+/* to use extra config set for specific user group*/
 /**************************************************/
-void setupConfExtra(char * userId,char *extraId)
+void setupConfExtra(char * userId, char *extraId)
 {
   ezxml_t xml;
   char useridfull[USERMAXLN]; /* userid@extraid */
@@ -242,8 +249,8 @@ int regExMatch(const char *inStr, const char *regEx, int caseSensitive)
 
 /**************************************************/
 /*  get a value for name from Conf file           */
-/*  the name[aa/bb/cc] means the path             */
-/*  if ID is set, extraSet value is overlayed */
+/*  the name[aa/bb/cc] means the tree path        */
+/*  extraSet value is overlayed, if exists        */
 /**************************************************/
 char *getConfValue(char *name)
 {
@@ -330,7 +337,7 @@ char *getConfValueExtra(char *name)
 
 /***************************************************/
 /*  get a value for AuthServer param from Conf file*/
-/*  the name[AuthServer/bb/cc] means the path      */
+/*  the name[AuthServer/bb/cc] means the tree path */
 /***************************************************/
 char *getConfAuthServer(char *name)
 {
@@ -376,9 +383,10 @@ char *getConfAuthServer(char *name)
   return pValue;
 }
 
-/**********************************/
-/* select next authserver setting */
-/**********************************/
+/**************************************************/
+/* select next authserver setting                 */
+/* the pointer to the next setting is saved inside*/
+/**************************************************/
 int selectNextAuthServer(void){
 
   ezxml_t xmlTmp; /* temporary variable */
