@@ -327,12 +327,15 @@ void putCloseMsg(time_t timeOut, time_t timeIn)
 /*****************************/
 void closeExit(int signo)
 {
-  /* write closing information to database */
-  PutSessionEndToDb(cookie, mode[connectionMode]);
-
   /* signal is disabled */
   signalx(SIGTERM, SIG_DFL);
 
+  /* write closing information to database */
+  PutSessionEndToDb(cookie, mode[connectionMode]);
+
+  /* delete old session log record from database */
+  DeleteOldSessionInDb();
+  
   /* ignore redundant process */
   if(connectionMode!=DUPLICATED){
 
