@@ -2,7 +2,7 @@
 
 #######################################
 ##
-## shwo opengate status for MRTG
+## show opengate status for MRTG
 ##
 ##   1 line : IPv6 Users
 ##   2 line : Total Users
@@ -25,9 +25,9 @@ tmp_6="/tmp/og_count_6.tmp"
 process="opengatesrv.cgi"
 
 
-######################################################3
+######################################################
 
-ps ax | grep $process > $tmp_all
+ps ax | grep $process  | grep -v "grep $process" > $tmp_all
 
 COUNT=`wc -l $tmp_all | awk '{print $1}'`
 
